Introduction
============

GenoPandas is a library that provides various datastructures to support
manipulation, querying and plotting of genomic data in Python. To do so,
GenoPandas provides several pandas-based data structures, such as the
``GenomicDataFrame`` and ``AnnotatedMatrix`` classes, which can be used to
store different types of genomic data. For basic analyses, these classes
also provide a variety of different manipulation and plotting functions.

.. toctree::
   :maxdepth: 2
   :hidden:

   self
   installation
   usage
   api
   contributing
   authors
   history
